config

package
v0.0.0-...-637ab5e Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 12, 2021 License: MIT Imports: 1 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Configuration

type Configuration struct {
	// ApiAddr is the address where clients can submit a job on using REST/JSON
	ApiAddr string

	// AltApiAddr is the address where clients can submit a job on using gRPC
	AltApiAddr string

	// ClusterAddr is the address where transcoders can join on using gRPC
	ClusterAddr string
}

func (*Configuration) Validate

func (cfg *Configuration) Validate() error

Jump to