Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Configuration ¶
type Configuration struct {
// ApiAddr is the address where clients can submit a job on using REST/JSON
ApiAddr string
// AltApiAddr is the address where clients can submit a job on using gRPC
AltApiAddr string
// ClusterAddr is the address where transcoders can join on using gRPC
ClusterAddr string
}
func (*Configuration) Validate ¶
func (cfg *Configuration) Validate() error
Click to show internal directories.
Click to hide internal directories.